==> qis-1.0.5.tar.gz: qis-1.0.5/qis/utils/__init__.py <==

from qis.utils.dates import (
    TimePeriod,
    find_min_time,
    generate_dates_schedule,
    generate_is_weekend,
    generate_rebalancing_indicators,
    generate_sample_dates,
    get_an_factor,
    get_current_date,
    get_data_at_date,
    get_month_days,
    get_period_days,
    get_return_an,
    get_sample_dates_idx,
    get_time_period,
    get_time_period_label,
    get_time_period_shifted_by_years,
    get_today_eod_with_tz,
    get_today_str,
    get_vol_an,
    get_weekday,
    get_year_quarter,
    get_ytd_time_period,
    infer_an_from_data,
    is_business_day,
    is_leap_year,
    months_between,
    rebase_model_dates,
    separate_number_from_string,
    shift_date_by_day,
    shift_date_by_month,
    shift_dates_by_n_years,
    shift_dates_by_year,
    shift_time_period_by_days,
    split_df_by_freq,
    tz_localize_dates
)


from qis.utils.df_agg import (
    abssum,
    abssum_negative,
    abssum_positive,
    agg_data_by_axis,
    agg_dfs,
    agg_median_mad,
    get_signed_np_data,
    nanmean,
    nanmean_clip,
    nanmean_positive,
    nanmedian,
    nansum,
    nansum_clip,
    nansum_negative,
    nansum_positive,
    pd_agg_func,
    sum_weighted
)

from qis.utils.df_cut import (
    add_classification,
    add_hue_fixed_years,
    add_hue_years,
    add_quantile_classification,
    sort_index_by_hue,
    x_bins_cut
)

from qis.utils.df_freq import (
    agg_remained_data_on_right,
    df_asfreq,
    df_index_to_str,
    df_resample_at_freq,
    df_resample_at_int_index,
    df_resample_at_other_index
)

from qis.utils.df_groups import (
    agg_df_by_group_with_avg,
    agg_df_by_groups,
    agg_df_by_groups_ax1,
    fill_df_with_group_avg,
    get_group_dict,
    sort_df_by_index_group,
    split_df_by_groups
)

from qis.utils.df_melt import (
    melt_df_by_columns,
    melt_paired_df,
    melt_scatter_data_with_xdata,
    melt_scatter_data_with_xvar,
    melt_signed_paired_df
)

from qis.utils.df_ops import (
    align_column_to_index,
    align_df1_to_df2,
    align_dfs_dict_with_df,
    align_index_to_index,
    compute_last_score,
    concat_at_start_date,
    df12_merge_with_tz,
    df_concat_with_tz,
    df_filter_like,
    df_indicator_like,
    df_indicator_like_other,
    df_joint_indicator,
    df_ones_like,
    df_time_dict_to_pd,
    df_zero_like,
    dfs_indicators,
    dfs_to_upper_lower_diag,
    drop_first_nan_data,
    factor_dict_to_asset_dict,
    get_df_subset_index,
    get_first_before_non_nan_index,
    get_first_last_non_nan_date,
    get_first_non_nan_values,
    get_last_non_nan_values,
    merge_on_column,
    missing_zero_ratios_after_first_non_nan,
    multiply_df_by_dt,
    norm_df_by_ax_mean,
    np_txy_tensor_to_pd_dict,
    rename_column_names,
    series_to_dict
)

from qis.utils.df_str import (
    date_to_str,
    df_all_to_str,
    df_index_to_str,
    df_to_numeric,
    df_to_str,
    df_with_ci_to_str,
    float_to_str,
    get_fmt_str,
    join_str_series,
    series_to_date_str,
    series_to_numeric,
    series_to_str,
    series_values_to_str,
    str_to_float,
    timeseries_df_to_str
)

from qis.utils.df_to_weights import (
    compute_long_short_ind,
    compute_long_short_ind_by_row,
    df_nans_to_one_zero,
    df_to_equal_weight_allocation,
    df_to_max_score,
    df_to_top_n_indicators,
    df_to_weight_allocation_sum1,
    fill_long_short_signal,
    get_weights,
    mult_df_columns_with_vector,
    mult_df_columns_with_vector_group
)

from qis.utils.generic import (
    ValueType,
    ColVar,
    ColumnData,
    column_datas_to_df,
    EnumMap,
    DotDict
)


from qis.utils.np_ops import (
    compute_expanding_power,
    compute_histogram_data,
    compute_paired_signs,
    find_nearest,
    np_array_to_df_columns,
    np_array_to_df_index,
    np_array_to_matrix,
    np_array_to_n_column_array,
    np_array_to_t_rows_array,
    np_get_sorted_idx,
    np_matrix_add_array,
    np_nonan_weighted_avg,
    np_shift,
    running_mean,
    to_finite_np,
    to_finite_ratio,
    to_finite_reciprocal
)

from qis.utils.ols import (
    estimate_alpha_beta_paired_dfs,
    estimate_ols_alpha_beta,
    fit_ols,
    get_ols_x,
    reg_model_params_to_str
)

from qis.utils.sampling import (
    TrainLivePeriod,
    TrainLiveSamples,
    get_data_samples_df,
    split_to_samples,
    split_to_train_live_samples
)

from qis.utils.struct_ops import (
    assert_list_subset,
    assert_list_unique,
    flatten,
    flatten_dict_tuples,
    list_diff,
    list_intersection,
    list_to_unique_and_dub,
    merge_lists_unique,
    move_item_to_first,
    separate_number_from_string,
    split_dict,
    to_flat_list,
    update_kwargs
)

from qis.file_utils import timer

==> qis-1.0.11.tar.gz: qis-1.0.11/qis/utils/__init__.py <==

from qis.utils.dates import (
    TimePeriod,
    find_min_time,
    generate_dates_schedule,
    generate_is_weekend,
    generate_rebalancing_indicators,
    generate_sample_dates,
    get_an_factor,
    get_current_date,
    get_data_at_date,
    get_month_days,
    get_period_days,
    get_return_an,
    get_sample_dates_idx,
    get_time_period,
    get_time_period_label,
    get_time_period_shifted_by_years,
    get_today_eod_with_tz,
    get_today_str,
    get_vol_an,
    get_weekday,
    get_year_quarter,
    get_ytd_time_period,
    infer_an_from_data,
    is_business_day,
    is_leap_year,
    months_between,
    rebase_model_dates,
    separate_number_from_string,
    shift_date_by_day,
    shift_date_by_month,
    shift_dates_by_n_years,
    shift_dates_by_year,
    shift_time_period_by_days,
    split_df_by_freq,
    tz_localize_dates,
    generate_fixed_maturity_rolls
)


from qis.utils.df_agg import (
    abssum,
    abssum_negative,
    abssum_positive,
    agg_data_by_axis,
    agg_dfs,
    agg_median_mad,
    get_signed_np_data,
    nanmean,
    nanmean_clip,
    nanmean_positive,
    nanmedian,
    nansum,
    nansum_clip,
    nansum_negative,
    nansum_positive,
    pd_agg_func,
    sum_weighted
)

from qis.utils.df_cut import (
    add_classification,
    add_hue_fixed_years,
    add_hue_years,
    add_quantile_classification,
    sort_index_by_hue,
    x_bins_cut
)

from qis.utils.df_freq import (
    agg_remained_data_on_right,
    df_asfreq,
    df_index_to_str,
    df_resample_at_freq,
    df_resample_at_int_index,
    df_resample_at_other_index
)

from qis.utils.df_groups import (
    agg_df_by_group_with_avg,
    agg_df_by_groups,
    agg_df_by_groups_ax1,
    fill_df_with_group_avg,
    get_group_dict,
    sort_df_by_index_group,
    split_df_by_groups
)

from qis.utils.df_melt import (
    melt_df_by_columns,
    melt_paired_df,
    melt_scatter_data_with_xdata,
    melt_scatter_data_with_xvar,
    melt_signed_paired_df
)

from qis.utils.df_ops import (
    align_column_to_index,
    align_df1_to_df2,
    align_dfs_dict_with_df,
    align_index_to_index,
    compute_last_score,
    concat_at_start_date,
    df12_merge_with_tz,
    df_concat_with_tz,
    df_filter_like,
    df_indicator_like,
    df_indicator_like_other,
    df_joint_indicator,
    df_ones_like,
    df_time_dict_to_pd,
    df_zero_like,
    dfs_indicators,
    dfs_to_upper_lower_diag,
    drop_first_nan_data,
    factor_dict_to_asset_dict,
    get_df_subset_index,
    get_first_before_non_nan_index,
    get_first_last_non_nan_date,
    get_first_non_nan_values,
    get_last_non_nan_values,
    get_last_non_nan,
    merge_on_column,
    missing_zero_ratios_after_first_non_nan,
    multiply_df_by_dt,
    norm_df_by_ax_mean,
    np_txy_tensor_to_pd_dict,
    series_to_dict
)

from qis.utils.df_str import (
    date_to_str,
    df_all_to_str,
    df_index_to_str,
    df_to_numeric,
    df_to_str,
    df_with_ci_to_str,
    float_to_str,
    get_fmt_str,
    join_str_series,
    series_to_date_str,
    series_to_numeric,
    series_to_str,
    series_values_to_str,
    str_to_float,
    timeseries_df_to_str
)

from qis.utils.df_to_weights import (
    compute_long_short_ind,
    compute_long_short_ind_by_row,
    df_nans_to_one_zero,
    df_to_equal_weight_allocation,
    df_to_max_score,
    df_to_top_n_indicators,
    df_to_weight_allocation_sum1,
    fill_long_short_signal,
    get_weights,
    mult_df_columns_with_vector,
    mult_df_columns_with_vector_group
)

from qis.utils.generic import (
    ValueType,
    ColVar,
    ColumnData,
    column_datas_to_df,
    EnumMap,
    DotDict
)


from qis.utils.np_ops import (
    compute_expanding_power,
    compute_histogram_data,
    compute_paired_signs,
    find_nearest,
    np_array_to_df_columns,
    np_array_to_df_index,
    np_array_to_matrix,
    np_array_to_n_column_array,
    np_array_to_t_rows_array,
    np_get_sorted_idx,
    np_matrix_add_array,
    np_nonan_weighted_avg,
    np_shift,
    running_mean,
    to_finite_np,
    to_finite_ratio,
    to_finite_reciprocal,
    repeat_by_columns,
    repeat_by_rows
)

from qis.utils.ols import (
    estimate_alpha_beta_paired_dfs,
    estimate_ols_alpha_beta,
    fit_ols,
    get_ols_x,
    reg_model_params_to_str
)

from qis.utils.sampling import (
    TrainLivePeriod,
    TrainLiveSamples,
    get_data_samples_df,
    split_to_samples,
    split_to_train_live_samples
)

from qis.utils.struct_ops import (
    assert_list_subset,
    assert_list_unique,
    flatten,
    flatten_dict_tuples,
    list_diff,
    list_intersection,
    list_to_unique_and_dub,
    merge_lists_unique,
    move_item_to_first,
    separate_number_from_string,
    split_dict,
    to_flat_list,
    update_kwargs
)

from qis.file_utils import timer
